#include <glib.h>
#include <glib-object.h>
#include "network.h"
#define NETWORK_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), TYPE_NETWORK, NetworkPrivate))
enum
{
	PROP_0, /* unused property */
	PROP_DIALINSTALLED,
	PROP_HOSTNAME,
	PROP_SMARDHCPD,
	PROP_SMBDESC,
	PROP_SMBINSTALLED,
	PROP_SMBUSE,
	PROP_1 /* unused property */
};
struct _NetworkPrivate {
	GList* interface;
	GList* dialing;
	GList* order;
	GList* statichost;
	gchar* dialinstalled;
	gchar* hostname;
	gchar* smardhcpd;
	gchar* smbdesc;
	gchar* smbinstalled;
	guchar smbuse;
};

/* Parent class */
static GObjectClass *parent_class = NULL;
/* Prototypes definition */
static void network_init (Network*obj);
static void network_class_init (NetworkClass*obj);
static void network_finalize (GObject* object);
static void network_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
static void network_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);

GType
network_get_type (void)
{
	static GType object_type = 0;
	if (!object_type) {
		static const GTypeInfo object_info =
		{
			sizeof (NetworkClass),
			NULL, /* base init */
			NULL, /* base finalize */
			(GClassInitFunc) network_class_init,
			NULL, /* class finalize */
			NULL, /* class data */
			sizeof (Network),
			0, /* number of pre-allocs */
			(GInstanceInitFunc) network_init,
		};
		object_type = g_type_register_static (G_TYPE_OBJECT, "Network", &object_info, 0);
	}
	return object_type;
}

static void
network_class_init (NetworkClass *klass)
{
	GObjectClass *gobject_class;
	parent_class = g_type_class_peek_parent (klass);
	gobject_class = G_OBJECT_CLASS (klass);
	gobject_class->finalize = network_finalize;
	gobject_class->set_property = network_set_property;
	gobject_class->get_property = network_get_property;
	g_object_class_install_property (gobject_class,
			PROP_DIALINSTALLED,
			g_param_spec_string ("dialinstalled", "dialinstalled", "dialinstalled", NULL, G_PARAM_READWRITE));
	g_object_class_install_property (gobject_class,
			PROP_HOSTNAME,
			g_param_spec_string ("hostname", "hostname", "hostname", NULL, G_PARAM_READWRITE));
	g_object_class_install_property (gobject_class,
			PROP_SMARDHCPD,
			g_param_spec_string ("smardhcpd", "smardhcpd", "smardhcpd", NULL, G_PARAM_READWRITE));
	g_object_class_install_property (gobject_class,
			PROP_SMBDESC,
			g_param_spec_string ("smbdesc", "smbdesc", "smbdesc", NULL, G_PARAM_READWRITE));
	g_object_class_install_property (gobject_class,
			PROP_SMBINSTALLED,
			g_param_spec_string ("smbinstalled", "smbinstalled", "smbinstalled", NULL, G_PARAM_READWRITE));
	g_object_class_install_property (gobject_class,
			PROP_SMBUSE,
			g_param_spec_uchar ("smbuse", "smbuse", "smbuse", 0, 255, 0, G_PARAM_READWRITE));
	g_type_class_add_private (gobject_class, sizeof (NetworkPrivate));
}

static void
network_init (Network *object)
{
	object->private_data = NETWORK_GET_PRIVATE (object);
	object->private_data->dialinstalled = NULL;
	object->private_data->hostname = NULL;
	object->private_data->smardhcpd = NULL;
	object->private_data->smbdesc = NULL;
	object->private_data->smbinstalled = NULL;
	object->private_data->interface = NULL;
	object->private_data->dialing = NULL;
	object->private_data->order = NULL;
	object->private_data->statichost = NULL;
}

static void
network_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
{
	Network *self;
	gchar tmp;
	self = NETWORK (object);
	switch (prop_id) {
		case PROP_DIALINSTALLED:
			network_set_dialinstalled (self, g_value_get_string(value));
			break;
		case PROP_HOSTNAME:
			network_set_hostname (self, g_value_get_string(value));
			break;
		case PROP_SMARDHCPD:
			network_set_smardhcpd (self, g_value_get_string(value));
			break;
		case PROP_SMBDESC:
			network_set_smbdesc (self, g_value_get_string(value));
			break;
		case PROP_SMBINSTALLED:
			network_set_smbinstalled (self, g_value_get_string(value));
			break;
		case PROP_SMBUSE:
			network_set_smbuse (self, g_value_get_uchar(value));
			break;
		default:
			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
			break;
	}
}

static void
network_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
{
	Network *self;
	self = NETWORK (object);
	switch (prop_id) {
		case PROP_DIALINSTALLED:
			g_value_set_string (value, network_get_dialinstalled (self));
			break;
		case PROP_HOSTNAME:
			g_value_set_string (value, network_get_hostname (self));
			break;
		case PROP_SMARDHCPD:
			g_value_set_string (value, network_get_smardhcpd (self));
			break;
		case PROP_SMBDESC:
			g_value_set_string (value, network_get_smbdesc (self));
			break;
		case PROP_SMBINSTALLED:
			g_value_set_string (value, network_get_smbinstalled (self));
			break;
		case PROP_SMBUSE:
			g_value_set_uchar (value, network_get_smbuse (self));
			break;
		default:
			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
	}
}

Network*
network_new (void)
{
	Network* ret;
	ret = g_object_new (TYPE_NETWORK, NULL);
	g_assert (ret);
	return ret;
}

static void
network_finalize (GObject *object)
{
	/* cast to this type */
	Network* self;
	GList *list;
	self = NETWORK(object);
	g_free (self->private_data->dialinstalled);
	g_free (self->private_data->hostname);
	g_free (self->private_data->smardhcpd);
	g_free (self->private_data->smbdesc);
	g_free (self->private_data->smbinstalled);
	list = self->private_data->interface;
	g_list_foreach(list, (GFunc)g_free, NULL);
	g_list_free (list);
	list = self->private_data->dialing;
	g_list_foreach(list, (GFunc)g_free, NULL);
	g_list_free (list);
	list = self->private_data->order;
	g_list_foreach(list, (GFunc)g_free, NULL);
	g_list_free (list);
	list = self->private_data->statichost;
	g_list_foreach(list, (GFunc)g_free, NULL);
	g_list_free (list);
}

gchar*
network_get_dialinstalled (Network* self)
{
	g_assert (self);
	return self->private_data->dialinstalled;
}

void
network_set_dialinstalled (Network* self, const gchar* data)
{
	gchar *tmp = (gchar *) g_strdup(data);
	g_assert(self);
	g_free (self->private_data->dialinstalled);
	self->private_data->dialinstalled = tmp;
}

gchar*
network_get_hostname (Network* self)
{
	g_assert (self);
	return self->private_data->hostname;
}

void
network_set_hostname (Network* self, const gchar* data)
{
	gchar *tmp = (gchar *) g_strdup(data);
	g_assert(self);
	g_free (self->private_data->hostname);
	self->private_data->hostname = tmp;
}

gchar*
network_get_smardhcpd (Network* self)
{
	g_assert (self);
	return self->private_data->smardhcpd;
}

void
network_set_smardhcpd (Network* self, const gchar* data)
{
	gchar *tmp = (gchar *) g_strdup(data);
	g_assert(self);
	g_free (self->private_data->smardhcpd);
	self->private_data->smardhcpd = tmp;
}

gchar*
network_get_smbdesc (Network* self)
{
	g_assert (self);
	return self->private_data->smbdesc;
}

void
network_set_smbdesc (Network* self, const gchar* data)
{
	gchar *tmp = (gchar *) g_strdup(data);
	g_assert(self);
	g_free (self->private_data->smbdesc);
	self->private_data->smbdesc = tmp;
}

gchar*
network_get_smbinstalled (Network* self)
{
	g_assert (self);
	return self->private_data->smbinstalled;
}

void
network_set_smbinstalled (Network* self, const gchar* data)
{
	gchar *tmp = (gchar *) g_strdup(data);
	g_assert(self);
	g_free (self->private_data->smbinstalled);
	self->private_data->smbinstalled = tmp;
}

guchar
network_get_smbuse (Network* self)
{
	g_assert (self);
	return self->private_data->smbuse;
}

void
network_set_smbuse (Network* self, guchar data)
{
	g_assert(self);
	self->private_data->smbuse = data;
}

GList*
network_get_interface (Network* self)
{
	g_assert (self);
	return self->private_data->interface;
}

void
network_set_interface (Network* self, GList* data)
{
	g_assert(self);
	self->private_data->interface = data;
}

GList*
network_get_dialing (Network* self)
{
	g_assert (self);
	return self->private_data->dialing;
}

void
network_set_dialing (Network* self, GList* data)
{
	g_assert(self);
	self->private_data->dialing = data;
}

GList*
network_get_order (Network* self)
{
	g_assert (self);
	return self->private_data->order;
}

void
network_set_order (Network* self, GList* data)
{
	g_assert(self);
	self->private_data->order = data;
}

GList*
network_get_statichost (Network* self)
{
	g_assert (self);
	return self->private_data->statichost;
}

void
network_set_statichost (Network* self, GList* data)
{
	g_assert(self);
	self->private_data->statichost = data;
}

